@@ -36,6 +36,7 @@
 #include "treenodevisitor.h"
 #include "types.h"
 #include "utils.h"
+#include "feedretriever.h"
 
 #include <Syndication/Syndication>
 
@@ -180,8 +181,12 @@ Akregator::Feed *Akregator::Feed::fromOPML(QDomElement e, Backend::Storage *stor
     feed->setMaxArticleNumber(maxArticleNumber);
     feed->setMarkImmediatelyAsRead(markImmediatelyAsRead);
     feed->setLoadLinkedWebsite(loadLinkedWebsite);
-    feed->loadArticles(); // TODO: make me fly: make this delayed
 
+    if (!feed->d->archive && storage) {
+        // Instead of loading the articles, we use the cache from storage
+        feed->d->archive = storage->archiveFor(xmlUrl);
+        feed->d->totalCount = feed->d->archive->totalCount();
+    }
     return feed;
 }
 
@@ -248,7 +253,7 @@ void Akregator::Feed::loadArticles()
 
     QStringList list = d->archive->articles();
     for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
-        Article mya(*it, this);
+        Article mya(*it, this, d->archive);
         d->articles[mya.guid()] = mya;
         if (mya.isDeleted()) {
             d->deletedArticles.append(mya);
@@ -399,9 +404,6 @@ bool Akregator::Feed::isFetching() const
 void Akregator::Feed::setMarkImmediatelyAsRead(bool enabled)
 {
     d->markImmediatelyAsRead = enabled;
-    if (enabled) {
-        createMarkAsReadJob()->start();
-    }
 }
 
 void Akregator::Feed::setUseNotification(bool enabled)
@@ -530,7 +532,7 @@ void Akregator::Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchO
             interval = Settings::autoFetchInterval() * 60;
         }
 
-        uint lastFetch = d->archive->lastFetch();
+        uint lastFetch = d->archive->lastFetch().toTime_t();
 
         uint now = QDateTime::currentDateTimeUtc().toTime_t();
 
@@ -681,7 +683,7 @@ void Akregator::Feed::tryFetch()
     d->loader = Syndication::Loader::create(this, SLOT(fetchCompleted(Syndication::Loader *,
                                                                       Syndication::FeedPtr,
                                                                       Syndication::ErrorCode)));
-    d->loader->loadFrom(QUrl(d->xmlUrl));
+    d->loader->loadFrom(QUrl(d->xmlUrl), new FeedRetriever());
 }
 
 void Akregator::Feed::slotImageFetched(const QPixmap &image)
@@ -739,7 +741,7 @@ void Akregator::Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPt
 void Akregator::Feed::markAsFetchedNow()
 {
     if (d->archive) {
-        d->archive->setLastFetch(QDateTime::currentDateTimeUtc().toTime_t());
+        d->archive->setLastFetch(QDateTime::currentDateTimeUtc());
     }
 }
 
